[svn-commits] tilghman: branch tilghman/str_substitution r185668 - in /team/tilghman/str_su...

SVN commits to the Digium repositories svn-commits at lists.digium.com
Tue Mar 31 17:41:27 CDT 2009


Author: tilghman
Date: Tue Mar 31 17:41:23 2009
New Revision: 185668

URL: http://svn.digium.com/svn-view/asterisk?view=rev&rev=185668
Log:
More documentation fixes

Modified:
    team/tilghman/str_substitution/apps/app_minivm.c
    team/tilghman/str_substitution/apps/app_voicemail.c
    team/tilghman/str_substitution/include/asterisk.h
    team/tilghman/str_substitution/include/asterisk/astobj2.h
    team/tilghman/str_substitution/include/asterisk/pbx.h
    team/tilghman/str_substitution/include/asterisk/res_odbc.h
    team/tilghman/str_substitution/include/asterisk/strings.h
    team/tilghman/str_substitution/main/ast_expr2f.c
    team/tilghman/str_substitution/main/manager.c
    team/tilghman/str_substitution/main/strings.c
    team/tilghman/str_substitution/main/taskprocessor.c
    team/tilghman/str_substitution/main/tdd.c
    team/tilghman/str_substitution/res/res_odbc.c

Modified: team/tilghman/str_substitution/apps/app_minivm.c
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/apps/app_minivm.c?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================
--- team/tilghman/str_substitution/apps/app_minivm.c (original)
+++ team/tilghman/str_substitution/apps/app_minivm.c Tue Mar 31 17:41:23 2009
@@ -1025,8 +1025,10 @@
  * sections, separated by a space character, in order to facilitate
  * breaking up the associated header across multiple lines.
  *
+ * \param end An expandable buffer for holding the result
+ * \param maxlen \see ast_str
+ * \param charset Character set in which the result should be encoded
  * \param start A string to be encoded
- * \param end An expandable buffer for holding the result
  * \param preamble The length of the first line already used for this string,
  * to ensure that each line maintains a maximum length of 76 chars.
  * \param postamble the length of any additional characters appended to the
@@ -1070,7 +1072,8 @@
 /*!
  * \brief Wraps a character sequence in double quotes, escaping occurences of quotes within the string.
  * \param from The string to work with.
- * \param to The string to write the modified quoted string. This buffer should be sufficiently larger than the from string, so as to allow it to be expanded by the surrounding quotes and escaping of internal quotes.
+ * \param buf The destination buffer to write the modified quoted string.
+ * \param maxlen Always zero.  \see ast_str
  * 
  * \return The destination string with quotes wrapped on it (the to field).
  */

Modified: team/tilghman/str_substitution/apps/app_voicemail.c
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/apps/app_voicemail.c?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================
--- team/tilghman/str_substitution/apps/app_voicemail.c (original)
+++ team/tilghman/str_substitution/apps/app_voicemail.c Tue Mar 31 17:41:23 2009
@@ -3874,7 +3874,8 @@
 /*!
  * \brief Wraps a character sequence in double quotes, escaping occurences of quotes within the string.
  * \param from The string to work with.
- * \param to The string to write the modified quoted string. This buffer should be sufficiently larger than the from string, so as to allow it to be expanded by the surrounding quotes and escaping of internal quotes.
+ * \param buf The buffer into which to write the modified quoted string.
+ * \param maxlen Always zero, but see \see ast_str
  * 
  * \return The destination string with quotes wrapped on it (the to field).
  */
@@ -3898,7 +3899,7 @@
 
 /*! \brief
  * fill in *tm for current time according to the proper timezone, if any.
- * Return tm so it can be used as a function argument.
+ * \return tm so it can be used as a function argument.
  */
 static const struct ast_tm *vmu_tm(const struct ast_vm_user *vmu, struct ast_tm *tm)
 {
@@ -3941,8 +3942,9 @@
  * sections, separated by a space character, in order to facilitate
  * breaking up the associated header across multiple lines.
  *
+ * \param end An expandable buffer for holding the result
+ * \param maxlen Always zero, but see \see ast_str
  * \param start A string to be encoded
- * \param end An expandable buffer for holding the result
  * \param preamble The length of the first line already used for this string,
  * to ensure that each line maintains a maximum length of 76 chars.
  * \param postamble the length of any additional characters appended to the

Modified: team/tilghman/str_substitution/include/asterisk.h
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/include/asterisk.h?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================
--- team/tilghman/str_substitution/include/asterisk.h (original)
+++ team/tilghman/str_substitution/include/asterisk.h Tue Mar 31 17:41:23 2009
@@ -146,10 +146,10 @@
  *
  * (note, this must be documented a lot more)
  * ast_add_profile allocates a generic 'counter' with a given name,
- * which can be shown with the command 'show profile <name>'
+ * which can be shown with the command 'core show profile &lt;name&gt;'
  *
  * The counter accumulates positive or negative values supplied by
- * ast_add_profile(), dividing them by the 'scale' value passed in the
+ * \see ast_add_profile(), dividing them by the 'scale' value passed in the
  * create call, and also counts the number of 'events'.
  * Values can also be taked by the TSC counter on ia32 architectures,
  * in which case you can mark the start of an event calling ast_mark(id, 1)

Modified: team/tilghman/str_substitution/include/asterisk/astobj2.h
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/include/asterisk/astobj2.h?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================
--- team/tilghman/str_substitution/include/asterisk/astobj2.h (original)
+++ team/tilghman/str_substitution/include/asterisk/astobj2.h Tue Mar 31 17:41:23 2009
@@ -388,6 +388,7 @@
  *
  * \param data_size The sizeof() of the user-defined structure.
  * \param destructor_fn The destructor function (can be NULL)
+ * \param debug_msg
  * \return A pointer to user-data.
  *
  * Allocates a struct astobj2 with sufficient space for the
@@ -397,23 +398,25 @@
  * - the refcount of the object just created is 1
  * - the returned pointer cannot be free()'d or realloc()'ed;
  *   rather, we just call ao2_ref(o, -1);
+ *
+ * @{
  */
 
 #ifdef REF_DEBUG
 
 
-#define ao2_t_alloc(arg1, arg2, arg3) __ao2_alloc_debug((arg1), (arg2), (arg3),  __FILE__, __LINE__, __PRETTY_FUNCTION__)
-#define ao2_alloc(arg1, arg2)         __ao2_alloc_debug((arg1), (arg2), "",  __FILE__, __LINE__, __PRETTY_FUNCTION__)
-
-#else
-
-#define ao2_t_alloc(arg1,arg2,arg3) __ao2_alloc((arg1), (arg2))
-#define ao2_alloc(arg1,arg2)        __ao2_alloc((arg1), (arg2))
+#define ao2_t_alloc(data_size, destructor_fn, debug_msg) __ao2_alloc_debug((data_size), (destructor_fn), (debug_msg),  __FILE__, __LINE__, __PRETTY_FUNCTION__)
+#define ao2_alloc(data_size, destructor_fn)              __ao2_alloc_debug((data_size), (destructor_fn), "",  __FILE__, __LINE__, __PRETTY_FUNCTION__)
+
+#else
+
+#define ao2_t_alloc(data_size, destructor_fn, debug_msg) __ao2_alloc((data_size), (destructor_fn))
+#define ao2_alloc((data_size), (destructor_fn))          __ao2_alloc((data_size), (destructor_fn))
 
 #endif
 void *__ao2_alloc_debug(const size_t data_size, ao2_destructor_fn destructor_fn, char *tag, char *file, int line, const char *funcname);
 void *__ao2_alloc(const size_t data_size, ao2_destructor_fn destructor_fn);
-
+/*! @} */
 
 /*! \brief
  * Reference/unreference an object and return the old refcount.
@@ -434,17 +437,20 @@
  * have a reference count to it, so the only case when the object
  * can go away is when we release our reference, and it is
  * the last one in existence.
+ *
+ * @{
  */
 
 #ifdef REF_DEBUG
-#define ao2_t_ref(arg1,arg2,arg3) __ao2_ref_debug((arg1), (arg2), (arg3),  __FILE__, __LINE__, __PRETTY_FUNCTION__)
-#define ao2_ref(arg1,arg2)        __ao2_ref_debug((arg1), (arg2), "",  __FILE__, __LINE__, __PRETTY_FUNCTION__)
-#else
-#define ao2_t_ref(arg1,arg2,arg3) __ao2_ref((arg1), (arg2))
-#define ao2_ref(arg1,arg2)        __ao2_ref((arg1), (arg2))
+#define ao2_t_ref(o,delta,tag) __ao2_ref_debug((o), (delta), (tag),  __FILE__, __LINE__, __PRETTY_FUNCTION__)
+#define ao2_ref(o,delta)       __ao2_ref_debug((o), (delta), "",  __FILE__, __LINE__, __PRETTY_FUNCTION__)
+#else
+#define ao2_t_ref(o,delta,tag) __ao2_ref((o), (delta))
+#define ao2_ref(o,delta)       __ao2_ref((o), (delta))
 #endif
 int __ao2_ref_debug(void *o, int delta, char *tag, char *file, int line, const char *funcname);
 int __ao2_ref(void *o, int delta);
+/*! @} */
 
 /*! \brief
  * Lock an object.
@@ -849,13 +855,15 @@
  *
  * \note When the returned object is no longer in use, ao2_ref() should
  * be used to free the additional reference possibly created by this function.
+ *
+ * @{
  */
 #ifdef REF_DEBUG
-#define ao2_t_callback(arg1,arg2,arg3,arg4,arg5) __ao2_callback_debug((arg1), (arg2), (arg3), (arg4), (arg5), __FILE__, __LINE__, __PRETTY_FUNCTION__)
-#define ao2_callback(arg1,arg2,arg3,arg4)        __ao2_callback_debug((arg1), (arg2), (arg3), (arg4), "", __FILE__, __LINE__, __PRETTY_FUNCTION__)
-#else
-#define ao2_t_callback(arg1,arg2,arg3,arg4,arg5) __ao2_callback((arg1), (arg2), (arg3), (arg4))
-#define ao2_callback(arg1,arg2,arg3,arg4)        __ao2_callback((arg1), (arg2), (arg3), (arg4))
+#define ao2_t_callback(c,flags,cb_fn,arg,tag) __ao2_callback_debug((c), (flags), (cb_fn), (arg), (tag), __FILE__, __LINE__, __PRETTY_FUNCTION__)
+#define ao2_callback(c,flags,cb_fn,arg)       __ao2_callback_debug((c), (flags), (cb_fn), (arg), "", __FILE__, __LINE__, __PRETTY_FUNCTION__)
+#else
+#define ao2_t_callback(c,flags,cb_fn,arg,tag) __ao2_callback((c), (flags), (cb_fn), (arg))
+#define ao2_callback(c,flags,cb_fn,arg)       __ao2_callback((c), (flags), (cb_fn), (arg))
 #endif
 void *__ao2_callback_debug(struct ao2_container *c, enum search_flags flags,
 						  ao2_callback_fn *cb_fn, void *arg, char *tag,
@@ -863,6 +871,7 @@
 void *__ao2_callback(struct ao2_container *c,
 					enum search_flags flags,
 					ao2_callback_fn *cb_fn, void *arg);
+/*! @} */
 
 /*! \brief
  * ao2_callback_data() is a generic function that applies cb_fn() to all objects

Modified: team/tilghman/str_substitution/include/asterisk/pbx.h
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/include/asterisk/pbx.h?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================
--- team/tilghman/str_substitution/include/asterisk/res_odbc.h (original)
+++ team/tilghman/str_substitution/include/asterisk/res_odbc.h Tue Mar 31 17:41:23 2009
@@ -35,7 +35,7 @@
 
 typedef enum { ODBC_SUCCESS=0, ODBC_FAIL=-1} odbc_status;
 
-/*! \brief Flags for use with ast_odbc_request_obj2 */
+/*! \brief Flags for use with \see ast_odbc_request_obj2 */
 enum {
 	RES_ODBC_SANITY_CHECK = (1 << 0),
 	RES_ODBC_INDEPENDENT_CONNECTION = (1 << 1),
@@ -102,7 +102,7 @@
 /*! 
  * \brief Retrieves a connected ODBC object
  * \param name The name of the ODBC class for which a connection is needed.
- * \param check Whether to ensure that a connection is valid before returning the handle.  Usually unnecessary.
+ * \param flags Set of flags used to control which connection is returned.
  * \retval ODBC object 
  * \retval  NULL if there is no connection available with the requested name.
  *
@@ -129,7 +129,7 @@
  * \brief Retrieve a stored ODBC object, if a transaction has been started.
  * \param chan Channel associated with the transaction.
  * \param objname Name of the database handle.  This name corresponds to the name passed
- * to ast_odbc_request_obj2 (or formerly, to ast_odbc_request_obj).  Note that the
+ * to \see ast_odbc_request_obj2 (or formerly, to ast_odbc_request_obj).  Note that the
  * existence of this parameter name explicitly allows for multiple transactions to be open
  * at once, albeit to different databases.
  * \retval A stored ODBC object, if a transaction was already started.
@@ -180,7 +180,7 @@
 /*!
  * \brief Find or create an entry describing the table specified.
  * \param database Name of an ODBC class on which to query the table
- * \param table Tablename to describe
+ * \param tablename Tablename to describe
  * \retval A structure describing the table layout, or NULL, if the table is not found or another error occurs.
  * When a structure is returned, the contained columns list will be
  * rdlock'ed, to ensure that it will be retained in memory.
@@ -200,7 +200,7 @@
 /*!
  * \brief Remove a cache entry from memory
  * \param database Name of an ODBC class (used to ensure like-named tables in different databases are not confused)
- * \param table Tablename for which a cached record should be removed
+ * \param tablename Tablename for which a cached record should be removed
  * \retval 0 if the cache entry was removed, or -1 if no matching entry was found.
  * \since 1.6.1
  */
@@ -213,7 +213,7 @@
 
 /*!\brief Wrapper for SQLGetData to use with dynamic strings
  * \param buf Address of the pointer to the ast_str structure.
- * \param maxlen The maximum size of the resulting string, or 0 for no limit.
+ * \param pmaxlen The maximum size of the resulting string, or 0 for no limit.
  * \param StatementHandle The statement handle from which to retrieve data.
  * \param ColumnNumber Column number (1-based offset) for which to retrieve data.
  * \param TargetType The SQL constant indicating what kind of data is to be retrieved (usually SQL_CHAR)

Modified: team/tilghman/str_substitution/include/asterisk/strings.h
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/include/asterisk/strings.h?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================
--- team/tilghman/str_substitution/include/asterisk/strings.h (original)
+++ team/tilghman/str_substitution/include/asterisk/strings.h Tue Mar 31 17:41:23 2009
@@ -451,7 +451,7 @@
 )
 
 /*!\brief Returns the current length of the string stored within buf.
- * \param A pointer to the ast_str string.
+ * \param buf A pointer to the ast_str structure.
  */
 AST_INLINE_API(
 size_t attribute_pure ast_str_strlen(struct ast_str *buf),
@@ -461,7 +461,8 @@
 )
 
 /*!\brief Returns the current maximum length (without reallocation) of the current buffer.
- * \param A pointer to the ast_str string.
+ * \param buf A pointer to the ast_str structure.
+ * \retval Current maximum length of the buffer.
  */
 AST_INLINE_API(
 size_t attribute_pure ast_str_size(struct ast_str *buf),
@@ -471,7 +472,8 @@
 )
 
 /*!\brief Returns the string buffer within the ast_str buf.
- * \param A pointer to the ast_str string.
+ * \param buf A pointer to the ast_str structure.
+ * \retval A pointer to the enclosed string.
  */
 AST_INLINE_API(
 char * attribute_pure ast_str_buffer(struct ast_str *buf),
@@ -480,6 +482,11 @@
 }
 )
 
+/*!\brief Truncates the enclosed string to the given length.
+ * \param buf A pointer to the ast_str structure.
+ * \param len Maximum length of the string.
+ * \retval A pointer to the resulting string.
+ */
 AST_INLINE_API(
 char *ast_str_truncate(struct ast_str *buf, ssize_t len),
 {

Modified: team/tilghman/str_substitution/main/ast_expr2f.c
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/main/ast_expr2f.c?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================
--- team/tilghman/str_substitution/main/ast_expr2f.c (original)
+++ team/tilghman/str_substitution/main/ast_expr2f.c Tue Mar 31 17:41:23 2009
@@ -1962,8 +1962,8 @@
 
 /** Setup the input buffer state to scan the given bytes. The next call to ast_yylex() will
  * scan from a @e copy of @a bytes.
- * @param bytes the byte buffer to scan
- * @param len the number of bytes in the buffer pointed to by @a bytes.
+ * @param yybytes the byte buffer to scan
+ * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
  * @param yyscanner The scanner object.
  * @return the newly allocated buffer state object.
  */
@@ -2124,7 +2124,7 @@
 }
 
 /** Set the current column.
- * @param line_number
+ * @param column_no
  * @param yyscanner The scanner object.
  */
 void ast_yyset_column (int  column_no , yyscan_t yyscanner)

Modified: team/tilghman/str_substitution/main/manager.c
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/main/manager.c?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================
--- team/tilghman/str_substitution/main/manager.c (original)
+++ team/tilghman/str_substitution/main/manager.c Tue Mar 31 17:41:23 2009
@@ -499,7 +499,7 @@
 }
 
 /*! \brief Get displayconnects config option.
- *  \param s manager session to get parameter from.
+ *  \param session manager session to get parameter from.
  *  \return displayconnects config option value.
  */
 static int manager_displayconnects (struct mansession_session *session)

Modified: team/tilghman/str_substitution/main/strings.c
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/main/strings.c?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================
--- team/tilghman/str_substitution/main/strings.c (original)
+++ team/tilghman/str_substitution/main/strings.c Tue Mar 31 17:41:23 2009
@@ -66,7 +66,7 @@
 		}
 		/*
 		 * Ask vsnprintf how much space we need. Remember that vsnprintf
-		 * does not count the final '\0' so we must add 1.
+		 * does not count the final <code>'\0'</code> so we must add 1.
 		 */
 		va_copy(aq, ap);
 		res = vsnprintf((*buf)->__AST_STR_STR + offset, (*buf)->__AST_STR_LEN - offset, fmt, aq);

Modified: team/tilghman/str_substitution/main/taskprocessor.c
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/main/taskprocessor.c?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================
--- team/tilghman/str_substitution/main/taskprocessor.c (original)
+++ team/tilghman/str_substitution/main/taskprocessor.c Tue Mar 31 17:41:23 2009
@@ -84,10 +84,10 @@
 /*! \brief tps_singletons is the astobj2 container for taskprocessor singletons */
 static struct ao2_container *tps_singletons;
 
-/*! \brief CLI 'taskprocessor ping <blah>' operation requires a ping condition */
+/*! \brief CLI <example>taskprocessor ping &lt;blah&gt;</example> operation requires a ping condition */
 static ast_cond_t cli_ping_cond;
 
-/*! \brief CLI 'taskprocessor ping <blah>' operation requires a ping condition lock */
+/*! \brief CLI <example>taskprocessor ping &lt;blah&gt;</example> operation requires a ping condition lock */
 AST_MUTEX_DEFINE_STATIC(cli_ping_cond_lock);
 
 /*! \brief The astobj2 hash callback for taskprocessors */
@@ -101,7 +101,7 @@
 /*! \brief Destroy the taskprocessor when its refcount reaches zero */
 static void tps_taskprocessor_destroy(void *tps);
 
-/*! \brief CLI 'taskprocessor ping <blah>' handler function */
+/*! \brief CLI <example>taskprocessor ping &lt;blah&gt;</example> handler function */
 static int tps_ping_handler(void *datap);
 
 /*! \brief Remove the front task off the taskprocessor queue */

Modified: team/tilghman/str_substitution/main/tdd.c
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/main/tdd.c?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================
--- team/tilghman/str_substitution/main/tdd.c (original)
+++ team/tilghman/str_substitution/main/tdd.c Tue Mar 31 17:41:23 2009
@@ -274,7 +274,9 @@
 	PUT_TDD_STOP;	/* Stop bit */ \
 } while(0);	
 
-/*! Generate TDD hold tone */
+/*! Generate TDD hold tone
+ * \param buf Result buffer
+ * \todo How big should this be??? */
 int tdd_gen_holdtone(unsigned char *buf)
 {
 	int bytes = 0;

Modified: team/tilghman/str_substitution/res/res_odbc.c
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/res/res_odbc.c?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================
--- team/tilghman/str_substitution/res/res_odbc.c (original)
+++ team/tilghman/str_substitution/res/res_odbc.c Tue Mar 31 17:41:23 2009
@@ -415,11 +415,12 @@
 
 /*!
  * \brief Find or create an entry describing the table specified.
- * \param obj An active ODBC handle on which to query the table
- * \param table Tablename to describe
+ * \param database Name of an ODBC class on which to query the table
+ * \param tablename Tablename to describe
  * \retval A structure describing the table layout, or NULL, if the table is not found or another error occurs.
  * When a structure is returned, the contained columns list will be
  * rdlock'ed, to ensure that it will be retained in memory.
+ * \since 1.6.1
  */
 struct odbc_cache_tables *ast_odbc_find_table(const char *database, const char *tablename)
 {




More information about the svn-commits mailing list
--- team/tilghman/str_substitution/include/asterisk/pbx.h (original)
+++ team/tilghman/str_substitution/include/asterisk/pbx.h Tue Mar 31 17:41:23 2009
@@ -415,9 +415,9 @@
  * \brief If an extension hint exists, return non-zero
  * 
  * \param hint buffer for hint
  * \param maxlen size of hint buffer
  * \param name buffer for name portion of hint
  * \param maxnamelen size of name buffer
  * \param c Channel from which to return the hint.  This is only important when the hint or name contains an expression to be expanded.
  * \param context which context to look in
  * \param exten which extension to search for
@@ -426,15 +426,16 @@
  * is found, a non zero value will be returned.
  * Otherwise, 0 is returned.
  */
-int ast_get_hint(char *hint, int maxlen, char *name, int maxnamelen, 
+int ast_get_hint(char *hint, int hintsize, char *name, int namesize,
 	struct ast_channel *c, const char *context, const char *exten);
+
 /*! 
  * \brief If an extension hint exists, return non-zero
  * 
  * \param hint buffer for hint
  * \param maxlen Maximum size of hint buffer (<0 to prevent growth, >0 to limit growth to that number of bytes, or 0 for unlimited growth)
  * \param name buffer for name portion of hint
  * \param maxnamelen Maxium size of name buffer (<0 to prevent growth, >0 to limit growth to that number of bytes, or 0 for unlimited growth)
  * \param c Channel from which to return the hint.  This is only important when the hint or name contains an expression to be expanded.
  * \param context which context to look in
  * \param exten which extension to search for
@@ -443,7 +444,7 @@
  * is found, a non zero value will be returned.
  * Otherwise, 0 is returned.
  */
-int ast_str_get_hint(struct ast_str **hint, int maxlen, struct ast_str **name, int maxnamelen, 
+int ast_str_get_hint(struct ast_str **hint, int hintsize, struct ast_str **name, int namesize,
 	struct ast_channel *c, const char *context, const char *exten);
 
 /*!
@@ -708,6 +709,8 @@
  *
  * \retval 0 on success 
  * \retval -1 on failure
+ *
+ * @{
  */
 int ast_context_remove_extension(const char *context, const char *extension, int priority,
 	const char *registrar);
@@ -721,6 +724,7 @@
 int ast_context_remove_extension_callerid2(struct ast_context *con, const char *extension,
 	int priority, const char *callerid, int matchcid, const char *registrar,
 	int already_locked);
+/*! @} */
 
 /*! 
  * \brief Add an ignorepat
@@ -1098,18 +1102,27 @@
  * \param chan Channel to execute on
  * \param function Data containing the function call string (will be modified)
  * \param workspace A pointer to safe memory to use for a return value 
+ * \param len the number of bytes in workspace
+ *
+ * This application executes a function in read mode on a given channel.
+ *
+ * \return zero on success, non-zero on failure
+ */
+int ast_func_read(struct ast_channel *chan, const char *function, char *workspace, size_t len);
+
+/*!
+ * \brief executes a read operation on a function 
+ *
+ * \param chan Channel to execute on
+ * \param function Data containing the function call string (will be modified)
  * \param str A dynamic string buffer into which to place the result.
- * \param len the number of bytes in workspace
+ * \param maxlen <0 if the dynamic buffer should not grow; >0 if the dynamic buffer should be limited to that number of bytes; 0 if the dynamic buffer has no upper limit
  *
  * This application executes a function in read mode on a given channel.
  *
  * \return zero on success, non-zero on failure
- *
- * @{
- */
-int ast_func_read(struct ast_channel *chan, const char *function, char *workspace, size_t len);
+ */
 int ast_func_read2(struct ast_channel *chan, const char *function, struct ast_str **str, int maxlen);
-/*! @} */
 
 /*!
  * \brief executes a write operation on a function
@@ -415,9 +415,9 @@
  * 
  * \param hint buffer for hint
- * \param maxlen size of hint buffer
+ * \param hintsize size of hint buffer, in bytes
  * \param name buffer for name portion of hint
@@ -415,9 +415,9 @@
  * \param name buffer for name portion of hint
- * \param maxnamelen size of name buffer
+ * \param namesize size of name buffer
  * \param c Channel from which to return the hint.  This is only important when the hint or name contains an expression to be expanded.
  * \param context which context to look in
@@ -426,15 +426,16 @@
  * 
  * \param hint buffer for hint
- * \param maxlen Maximum size of hint buffer (<0 to prevent growth, >0 to limit growth to that number of bytes, or 0 for unlimited growth)
+ * \param hintsize Maximum size of hint buffer (<0 to prevent growth, >0 to limit growth to that number of bytes, or 0 for unlimited growth)
  * \param name buffer for name portion of hint
@@ -426,15 +426,16 @@
  * \param name buffer for name portion of hint
- * \param maxnamelen Maxium size of name buffer (<0 to prevent growth, >0 to limit growth to that number of bytes, or 0 for unlimited growth)
+ * \param namesize Maximum size of name buffer (<0 to prevent growth, >0 to limit growth to that number of bytes, or 0 for unlimited growth)
  * \param c Channel from which to return the hint.  This is only important when the hint or name contains an expression to be expanded.
  * \param context which context to look in

Modified: team/tilghman/str_substitution/include/asterisk/res_odbc.h
URL: http://svn.digium.com/svn-view/asterisk/team/tilghman/str_substitution/include/asterisk/res_odbc.h?view=diff&rev=185668&r1=185667&r2=185668
==============================================================================